@@ -1,13 +1,13 @@
 import numpy as np
 import tensorflow as tf
 
-from .meta import as_free_parameter
+from .meta import as_free_parameter, parameter_model
 
 __all__ = [
-  'binary_init'
+  'BinaryInit', 'binary_init'
 ]
 
-def _binary(shape, dtype='float32', name=None):
+def binary(shape, dtype='float32', name=None):
   if isinstance(dtype, tf.dtypes.DType):
     _dtype = dtype.as_numpy_dtype
   else:
@@ -26,5 +26,6 @@ def _binary(shape, dtype='float32', name=None):
 
   return tf.constant(result, dtype=dtype, name=name)
 
-binary_init = as_free_parameter(_binary)
+BinaryInit = as_free_parameter(binary)
+binary_init = parameter_model(BinaryInit)()
 
