@@ -4,24 +4,19 @@ from .defaults import default_weight_init
 from .meta import Parameter, parameter_model
 
 __all__ = [
-  'NormalizedParameter',
-  'normalized_parameter'
+  'NormalizedParameter', 'normalized_parameter'
 ]
 
 class NormalizedParameter(Parameter):
-  def __init__(self, shape, w=default_weight_init, properties=None, name=None):
-    properties = dict() if properties is None else properties
-
+  def __init__(self, shape, w=default_weight_init, name=None, **properties):
     self.w = w(shape, **properties, name=name)
     self.broadcast = (slice(None, None, None), ) + tuple(
       None for _ in range(len(shape) - 1)
     )
 
     super(NormalizedParameter, self).__init__(
-      self.w,
-      shape=shape,
-      properties=properties,
-      name=name
+      self.w, shape=shape, name=name,
+      **properties,
     )
 
   def get_output_for(self, w):
@@ -36,4 +31,4 @@ class NormalizedParameter(Parameter):
   def get_output_shape_for(self, w_shape):
     return w_shape
 
-normalized_parameter = parameter_model(NormalizedParameter)
\ No newline at end of file
+normalized_parameter = parameter_model(NormalizedParameter)()
\ No newline at end of file
