@@ -4,7 +4,7 @@
 import numpy as np
 import tensorflow as tf
 
-from .meta import as_free_parameter
+from .meta import as_free_parameter, parameter_model
 
 __all__ = [
   'orthogonal_init'
@@ -19,5 +19,6 @@ def _orthogonal(shape, gain=1.0):
 
   return tf.reshape(W, shape)
 
-orthogonal_init = as_free_parameter(_orthogonal)
+OrthogonalInit = as_free_parameter(_orthogonal)
+orthogonal_init = parameter_model(OrthogonalInit)()
 
